//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop
#include "FormMain.h"

//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TfrmMain *frmMain;
//---------------------------------------------------------------------------
__fastcall TfrmMain::TfrmMain(TComponent* Owner)
  : TForm(Owner)
{
}

//---------------------------------------------------------------------------
// Just FYI:
// SNMP = Simple Network Management Protocol
// MIB  = Management Information Base
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
// OnShow-Eventhandler des Formulars
//---------------------------------------------------------------------------
void __fastcall TfrmMain::FormShow(TObject *Sender)
{
  pNicInfo = NULL;   // Zeiger auf Array mit tSTRUCTNICINFO-Strukturen
  int ilRetVal = RefreshNicInfo();  // Nic-Informationen aktualisieren
  switch(ilRetVal)
  {
    case ERROR_MIB_DLL:
      MessageBox(Handle, "Fehler beim Laden der INETMIB1.DLL!",
        "MIB Error", MB_ICONSTOP);
      break;
    case ERROR_MIB_WINSOCK:
      MessageBox(Handle, "Fehler beim Laden der Winsock DLL!",
        "MIB Error", MB_ICONSTOP);
      break;
    case ERROR_MIB_INIT:
      MessageBox(Handle, "MIB-Initialisierungsfeler !",
        "MIB Error", MB_ICONSTOP);
      break;
  }
}

//---------------------------------------------------------------------------
// Adapter-Informationen einlesen:
//---------------------------------------------------------------------------
int __fastcall TfrmMain::RefreshNicInfo(void)
{
  // ComboBox leeren:
  cmbAdapters->Items->Clear();

  // Eine MIBII-Istanz erzeugen:
  MibII MibInst;
  int ilRetVal = MibInst.Init();
  if (ilRetVal < 0) return ilRetVal;

  // Anzahl der Netzwerk-Adapter bestimmen:
  int ilNicCount = MibInst.GetNICCount(chkIncludeDialUp->Checked,
    chkIncludeLoopback->Checked);

  // Speicher reservieren und die Strukturen mit den Adapter-Infos fllen:
  if(ilNicCount > 0)
  {
    if(pNicInfo) delete [] pNicInfo;
    pNicInfo = new tSTRUCTNICINFO [ilNicCount];
    MibInst.GetNICInfo(pNicInfo);

    // Die ComboBox mit den Adapter-Namen fllen:
    for(int ilAdapter = 0; ilAdapter < ilNicCount; ilAdapter++)
      cmbAdapters->Items->Add(AnsiString((char*)pNicInfo[ilAdapter].Description));
    cmbAdapters->ItemIndex = 0;
    cmbAdaptersClick(0);
  }
  else
  {
    // Anzeige lschen:
    stTextCurrIp->Caption = EmptyStr;
    stTextSubnetMask->Caption = EmptyStr;
    stTextMac->Caption = EmptyStr;
    stTextType->Caption = EmptyStr;

    // Speicher ggf. aufrumen:
    if(pNicInfo)
    {
      delete [] pNicInfo;
      pNicInfo = NULL;
    }
  }
  return ilNicCount;
}

//---------------------------------------------------------------------------
// Konfiguration des selektierten Adapters anzeigen:
//---------------------------------------------------------------------------
void __fastcall TfrmMain::cmbAdaptersClick(TObject *Sender)
{
  if(pNicInfo != NULL)
  {
    int ilAdapter = cmbAdapters->ItemIndex;

    // Ip-Adresse anzeigen:
    stTextCurrIp->Caption = stTextCurrIp->Caption.sprintf("%d.%d.%d.%d",
      pNicInfo[ilAdapter].IP[0],pNicInfo[ilAdapter].IP[1],
      pNicInfo[ilAdapter].IP[2],pNicInfo[ilAdapter].IP[3]);

    // Subnet Mask
    stTextSubnetMask->Caption = stTextSubnetMask->Caption.sprintf("%d.%d.%d.%d",
      pNicInfo[ilAdapter].SubnetMask[0], pNicInfo[ilAdapter].SubnetMask[1],
      pNicInfo[ilAdapter].SubnetMask[2], pNicInfo[ilAdapter].SubnetMask[3]);

    // MAC anzeigen:
    AnsiString slMac = EmptyStr;
    for(int ilMacPart=0; ilMacPart<pNicInfo[ilAdapter].MACLength; ilMacPart++)
    {
      slMac+= IntToHex(pNicInfo[ilAdapter].MAC[ilMacPart],2);
      if(ilMacPart < pNicInfo[ilAdapter].MACLength-1) slMac+="-";
    }
    stTextMac -> Caption = slMac;

    // Adapter-Typ anzigen:
    stTextType->Caption = IntToStr(pNicInfo[ilAdapter].type);
  }
}

//---------------------------------------------------------------------------
// Click-Handler des Refresh-Buttons
//---------------------------------------------------------------------------
void __fastcall TfrmMain::btnRefreshClick(TObject *Sender)
{
  RefreshNicInfo();
}

//---------------------------------------------------------------------------
// Programm-Ende
//---------------------------------------------------------------------------
void __fastcall TfrmMain::btnCloseClick(TObject *Sender)
{
  Close();
}

//---------------------------------------------------------------------------
// OnDestroy-Eventhandler des Formulars
//---------------------------------------------------------------------------
void __fastcall TfrmMain::FormDestroy(TObject *Sender)
{
  // Speicher aufrumen:
  if(pNicInfo)
  {
    delete [] pNicInfo;
    pNicInfo = NULL;
  }
}
//---------------------------------------------------------------------------



